;* --------------------------------------------------------------------------------------
;*  Copyright (C) 2005 Maxim Integrated Products, Inc. All Rights Reserved.
;* 
;*  Permission is hereby granted, free of charge, to any person obtaining a
;*  copy of this software and associated documentation files (the "Software"),
;*  to deal in the Software without restriction, including without limitation
;*  the rights to use, copy, modify, merge, publish, distribute, sublicense,
;*  and/or sell copies of the Software, and to permit persons to whom the
;*  Software is furnished to do so, subject to the following conditions:
;* 
;*  The above copyright notice and this permission notice shall be included
;*  in all copies or substantial portions of the Software.
;* 
;*  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
;*  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
;*  MERCHANTABILITY,  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
;*  IN NO EVENT SHALL DALLAS SEMICONDUCTOR BE LIABLE FOR ANY CLAIM, DAMAGES
;*  OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
;*  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
;*  OTHER DEALINGS IN THE SOFTWARE.
;* 
;*  Filename:      maxq2000ev_6951.asm
;*  Description:   Utility functions for communicating with the MAX6951 EVkit
;*  Date:          Dec 8, 2005
;*  Version:       0.10
;*
;* --------------------------------------------------------------------------------------

$include (maxQ2000.inc)
$include (maxq2000_spi.inc)
$include (maxq2000ev_6951.inc)

;*******************************************************************************
;* Function:  max6951_transmit
;*
;* Sends/Receives a character to the MAX6951.
;*
;* Input:     ACC - the character to send.
;*
;* Output:    ACC - the character received.
;*
;* Destroys:
;*
;*******************************************************************************
max6951_transmit:
    move    PO5.4, #0           ; Set /CS low.
    call    spi_transmit
    move    PO5.4, #1           ; Set /CS high.
	RET

;*******************************************************************************
;* Function:  max6951_init
;*
;* Sets the correct SPI modes for talking to the MAX6951, enables SPI, and
;* 
;* initializes the MAX6951 to display 8 0s.
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC, A[0] -- A[10], PSF
;*
;*******************************************************************************
max6951_init:
	;	Set SPI baud rate 
    move    A[0], #2400h			; System clock is 16,000,000 Hz
    move    A[1], #00F4h
    move    A[2], #4240h			; Desired baud rate is 1,000,000 Hz 
    move    A[3], #000Fh
    call    spi_setbaudrate

    ; Set the appropriate modes for the 6951
    move    C, #SPI_IDLE_LOW		; idle = low
    call    spi_setclockpolarity
    move    C, #SPI_ACTIVE_EDGE		; active = rising edge
    call    spi_setclockphase
    move    C, #SPI_LENGTH_16		; always transfer 16 bits
    call    spi_setcharacterlength
    move    C, #SPI_MASTER_MODE		; MAXQ2000 is the master, MAX6951 is the slave
    call    spi_setmode

    ; Enable SPI
    move    C, #1
    call    spi_enable

	; Shutdown MAX6951 display first
	call max6951_shutdown

	; Set MAX6951 in hexadecimal decode mode
	move 	ACC, #MAX6951REG_DECODE
	sla4
	sla4
	or		#0FFh					; hexadecimal decode
	call    max6951_transmit

	; Set display intensity = 16/16
	move 	ACC, #MAX6951REG_INTENSITY
	sla4
	sla4
	or		#0Fh					; intensity = 16/16
	call    max6951_transmit

	; scan limit = 7
	move 	ACC, #MAX6951REG_SCANLIMIT
	sla4
	sla4
	or		#07h					; scan limit = 7 
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_enable
;*
;* Enables MAX6951 display.
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_enable:
	move 	ACC, #MAX6951REG_CONFIGURE
	sla4
	sla4
	or		#01h				; enable MAX6951
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_shutdown
;*
;* Shutdown MAX6951 display.
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_shutdown:
	move 	ACC, #MAX6951REG_CONFIGURE
	sla4
	sla4
	or		#00h				; shutdown MAX6951
	call    max6951_transmit
	RET	

;*******************************************************************************
;* Function:  max6951_set_all_0
;*
;* Set all digit registers to 0
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_0:
	move 	ACC, #6000h			;digit 0 = 0
	call    max6951_transmit
	move 	ACC, #6100h			;digit 1 = 0
	call    max6951_transmit
	move 	ACC, #6200h			;digit 2 = 0
	call    max6951_transmit
	move 	ACC, #6300h			;digit 3 = 0
	call    max6951_transmit
	move 	ACC, #6400h			;digit 4 = 0
	call    max6951_transmit
	move 	ACC, #6500h			;digit 5 = 0
	call    max6951_transmit
	move 	ACC, #6600h			;digit 6 = 0
	call    max6951_transmit
	move 	ACC, #6700h			;digit 7 = 0
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_0_nodecode
;*
;* Set all digit registers to 0 in no decode mode
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_0_nodecode:
	move 	ACC, #607Eh			;digit 0 = 0
	call    max6951_transmit
	move 	ACC, #617Eh			;digit 1 = 0
	call    max6951_transmit
	move 	ACC, #627Eh			;digit 2 = 0
	call    max6951_transmit
	move 	ACC, #637Eh			;digit 3 = 0
	call    max6951_transmit
	move 	ACC, #647Eh			;digit 4 = 0
	call    max6951_transmit
	move 	ACC, #657Eh			;digit 5 = 0
	call    max6951_transmit
	move 	ACC, #667Eh			;digit 6 = 0
	call    max6951_transmit
	move 	ACC, #677Eh			;digit 7 = 0
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_1
;*
;* Set all digit registers to 1
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_1:
	move 	ACC, #6001h			;digit 0 = 1
	call    max6951_transmit
	move 	ACC, #6101h			;digit 1 = 1
	call    max6951_transmit
	move 	ACC, #6201h			;digit 2 = 1
	call    max6951_transmit
	move 	ACC, #6301h			;digit 3 = 1
	call    max6951_transmit
	move 	ACC, #6401h			;digit 4 = 1
	call    max6951_transmit
	move 	ACC, #6501h			;digit 5 = 1
	call    max6951_transmit
	move 	ACC, #6601h			;digit 6 = 1
	call    max6951_transmit
	move 	ACC, #6701h			;digit 7 = 1
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_1_nodecode
;*
;* Set all digit registers to 1 in no decode mode
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_1_nodecode:
	move 	ACC, #6030h			;digit 0 = 1
	call    max6951_transmit
	move 	ACC, #6130h			;digit 1 = 1
	call    max6951_transmit
	move 	ACC, #6230h			;digit 2 = 1
	call    max6951_transmit
	move 	ACC, #6330h			;digit 3 = 1
	call    max6951_transmit
	move 	ACC, #6430h			;digit 4 = 1
	call    max6951_transmit
	move 	ACC, #6530h			;digit 5 = 1
	call    max6951_transmit
	move 	ACC, #6630h			;digit 6 = 1
	call    max6951_transmit
	move 	ACC, #6730h			;digit 7 = 1
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_2
;*
;* Set all digit registers to 2
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_2:
	move 	ACC, #6002h			;digit 0 = 2
	call    max6951_transmit
	move 	ACC, #6102h			;digit 1 = 2
	call    max6951_transmit
	move 	ACC, #6202h			;digit 2 = 2
	call    max6951_transmit
	move 	ACC, #6302h			;digit 3 = 2
	call    max6951_transmit
	move 	ACC, #6402h			;digit 4 = 2
	call    max6951_transmit
	move 	ACC, #6502h			;digit 5 = 2
	call    max6951_transmit
	move 	ACC, #6602h			;digit 6 = 2
	call    max6951_transmit
	move 	ACC, #6702h			;digit 7 = 2
	call    max6951_transmit 
	RET

;*******************************************************************************
;* Function:  max6951_set_all_2_nodecode	
;*
;* Set all digit registers to 2 in no decode mode
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_2_nodecode:
	move 	ACC, #606Dh			;digit 0 = 2
	call    max6951_transmit
	move 	ACC, #616Dh			;digit 1 = 2
	call    max6951_transmit
	move 	ACC, #626Dh			;digit 2 = 2
	call    max6951_transmit
	move 	ACC, #636Dh			;digit 3 = 2
	call    max6951_transmit
	move 	ACC, #646Dh			;digit 4 = 2
	call    max6951_transmit
	move 	ACC, #656Dh			;digit 5 = 2
	call    max6951_transmit
	move 	ACC, #666Dh			;digit 6 = 2
	call    max6951_transmit
	move 	ACC, #676Dh			;digit 7 = 2
	call    max6951_transmit 
	RET

;*******************************************************************************
;* Function:  max6951_set_all_3
;*
;* Set all digit registers to 3
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_3:
	move 	ACC, #6003h			;digit 0 = 3
	call    max6951_transmit
	move 	ACC, #6103h			;digit 1 = 3
	call    max6951_transmit
	move 	ACC, #6203h			;digit 2 = 3
	call    max6951_transmit
	move 	ACC, #6303h			;digit 3 = 3
	call    max6951_transmit
	move 	ACC, #6403h			;digit 4 = 3
	call    max6951_transmit
	move 	ACC, #6503h			;digit 5 = 3
	call    max6951_transmit
	move 	ACC, #6603h			;digit 6 = 3
	call    max6951_transmit
	move 	ACC, #6703h			;digit 7 = 3
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_3_nodecode	
;*
;* Set all digit registers to 3 in no decode mode	
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_3_nodecode:
	move 	ACC, #6079h			;digit 0 = 3
	call    max6951_transmit
	move 	ACC, #6179h			;digit 1 = 3
	call    max6951_transmit
	move 	ACC, #6279h			;digit 2 = 3
	call    max6951_transmit
	move 	ACC, #6379h			;digit 3 = 3
	call    max6951_transmit
	move 	ACC, #6479h			;digit 4 = 3
	call    max6951_transmit
	move 	ACC, #6579h			;digit 5 = 3
	call    max6951_transmit
	move 	ACC, #6679h			;digit 6 = 3
	call    max6951_transmit
	move 	ACC, #6779h			;digit 7 = 3
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_4
;*
;* Set all digit registers to 4
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_4:
	move 	ACC, #6004h			;digit 0 = 4
	call    max6951_transmit
	move 	ACC, #6104h			;digit 1 = 4
	call    max6951_transmit
	move 	ACC, #6204h			;digit 2 = 4
	call    max6951_transmit
	move 	ACC, #6304h			;digit 3 = 4
	call    max6951_transmit
	move 	ACC, #6404h			;digit 4 = 4
	call    max6951_transmit
	move 	ACC, #6504h			;digit 5 = 4
	call    max6951_transmit
	move 	ACC, #6604h			;digit 6 = 4
	call    max6951_transmit
	move 	ACC, #6704h			;digit 7 = 4
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_4_nodecode
;*
;* Set all digit registers to 4 in no decode mode
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_4_nodecode:
	move 	ACC, #6033h			;digit 0 = 4
	call    max6951_transmit
	move 	ACC, #6133h			;digit 1 = 4
	call    max6951_transmit
	move 	ACC, #6233h			;digit 2 = 4
	call    max6951_transmit
	move 	ACC, #6333h			;digit 3 = 4
	call    max6951_transmit
	move 	ACC, #6433h			;digit 4 = 4
	call    max6951_transmit
	move 	ACC, #6533h			;digit 5 = 4
	call    max6951_transmit
	move 	ACC, #6633h			;digit 6 = 4
	call    max6951_transmit
	move 	ACC, #6733h			;digit 7 = 4
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_5
;*
;* Set all digit registers to 5
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_5:
	move 	ACC, #6005h			;digit 0 = 5
	call    max6951_transmit
	move 	ACC, #6105h			;digit 1 = 5
	call    max6951_transmit
	move 	ACC, #6205h			;digit 2 = 5
	call    max6951_transmit
	move 	ACC, #6305h			;digit 3 = 5
	call    max6951_transmit
	move 	ACC, #6405h			;digit 4 = 5
	call    max6951_transmit
	move 	ACC, #6505h			;digit 5 = 5
	call    max6951_transmit
	move 	ACC, #6605h			;digit 6 = 5
	call    max6951_transmit
	move 	ACC, #6705h			;digit 7 = 5
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_5_nodecode
;*
;* Set all digit registers to 5 in no decode mode
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_5_nodecode:
	move 	ACC, #605Bh			;digit 0 = 5
	call    max6951_transmit
	move 	ACC, #615Bh			;digit 1 = 5
	call    max6951_transmit
	move 	ACC, #625Bh			;digit 2 = 5
	call    max6951_transmit
	move 	ACC, #635Bh			;digit 3 = 5
	call    max6951_transmit
	move 	ACC, #645Bh			;digit 4 = 5
	call    max6951_transmit
	move 	ACC, #655Bh			;digit 5 = 5
	call    max6951_transmit
	move 	ACC, #665Bh			;digit 6 = 5
	call    max6951_transmit
	move 	ACC, #675Bh			;digit 7 = 5
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_6
;*
;* Set all digit registers to 6
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_6:
	move 	ACC, #6006h			;digit 0 = 6
	call    max6951_transmit
	move 	ACC, #6106h			;digit 1 = 6
	call    max6951_transmit
	move 	ACC, #6206h			;digit 2 = 6
	call    max6951_transmit
	move 	ACC, #6306h			;digit 3 = 6
	call    max6951_transmit
	move 	ACC, #6406h			;digit 4 = 6
	call    max6951_transmit
	move 	ACC, #6506h			;digit 5 = 6
	call    max6951_transmit
	move 	ACC, #6606h			;digit 6 = 6
	call    max6951_transmit
	move 	ACC, #6706h			;digit 7 = 6
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_6_nodecode
;*
;* Set all digit registers to 6 in no decode mode
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_6_nodecode:
	move 	ACC, #605Fh			;digit 0 = 6
	call    max6951_transmit
	move 	ACC, #615Fh			;digit 1 = 6
	call    max6951_transmit
	move 	ACC, #625Fh			;digit 2 = 6
	call    max6951_transmit
	move 	ACC, #635Fh			;digit 3 = 6
	call    max6951_transmit
	move 	ACC, #645Fh			;digit 4 = 6
	call    max6951_transmit
	move 	ACC, #655Fh			;digit 5 = 6
	call    max6951_transmit
	move 	ACC, #665Fh			;digit 6 = 6
	call    max6951_transmit
	move 	ACC, #675Fh			;digit 7 = 6
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_7
;*
;* Set all digit registers to 7
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_7:
	move 	ACC, #6007h			;digit 0 = 7
	call    max6951_transmit
	move 	ACC, #6107h			;digit 1 = 7
	call    max6951_transmit
	move 	ACC, #6207h			;digit 2 = 7
	call    max6951_transmit
	move 	ACC, #6307h			;digit 3 = 7
	call    max6951_transmit
	move 	ACC, #6407h			;digit 4 = 7
	call    max6951_transmit
	move 	ACC, #6507h			;digit 5 = 7
	call    max6951_transmit
	move 	ACC, #6607h			;digit 6 = 7
	call    max6951_transmit
	move 	ACC, #6707h			;digit 7 = 7
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_7_nodecode		
;*
;* Set all digit registers to 7 in no decode mode	
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_7_nodecode:
	move 	ACC, #6070h			;digit 0 = 7
	call    max6951_transmit
	move 	ACC, #6170h			;digit 1 = 7
	call    max6951_transmit
	move 	ACC, #6270h			;digit 2 = 7
	call    max6951_transmit
	move 	ACC, #6370h			;digit 3 = 7
	call    max6951_transmit
	move 	ACC, #6470h			;digit 4 = 7
	call    max6951_transmit
	move 	ACC, #6570h			;digit 5 = 7
	call    max6951_transmit
	move 	ACC, #6670h			;digit 6 = 7
	call    max6951_transmit
	move 	ACC, #6770h			;digit 7 = 7
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_8
;*
;* Set all digit registers to 8
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_8:
	move 	ACC, #6008h			;digit 0 = 8
	call    max6951_transmit
	move 	ACC, #6108h			;digit 1 = 8
	call    max6951_transmit
	move 	ACC, #6208h			;digit 2 = 8
	call    max6951_transmit
	move 	ACC, #6308h			;digit 3 = 8
	call    max6951_transmit
	move 	ACC, #6408h			;digit 4 = 8
	call    max6951_transmit
	move 	ACC, #6508h			;digit 5 = 8
	call    max6951_transmit
	move 	ACC, #6608h			;digit 6 = 8
	call    max6951_transmit
	move 	ACC, #6708h			;digit 7 = 8
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_8_nodecode
;*
;* Set all digit registers to 8 in no decode mode
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_8_nodecode:
	move 	ACC, #607Fh			;digit 0 = 8
	call    max6951_transmit
	move 	ACC, #617Fh			;digit 1 = 8
	call    max6951_transmit
	move 	ACC, #627Fh			;digit 2 = 8
	call    max6951_transmit
	move 	ACC, #637Fh			;digit 3 = 8
	call    max6951_transmit
	move 	ACC, #647Fh			;digit 4 = 8
	call    max6951_transmit
	move 	ACC, #657Fh			;digit 5 = 8
	call    max6951_transmit
	move 	ACC, #667Fh			;digit 6 = 8
	call    max6951_transmit
	move 	ACC, #677Fh			;digit 7 = 8
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_9
;*
;* Set all digit registers to 9
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_9:
	move 	ACC, #6009h			;digit 0 = 9
	call    max6951_transmit
	move 	ACC, #6109h			;digit 1 = 9
	call    max6951_transmit
	move 	ACC, #6209h			;digit 2 = 9
	call    max6951_transmit
	move 	ACC, #6309h			;digit 3 = 9
	call    max6951_transmit
	move 	ACC, #6409h			;digit 4 = 9
	call    max6951_transmit
	move 	ACC, #6509h			;digit 5 = 9
	call    max6951_transmit
	move 	ACC, #6609h			;digit 6 = 9
	call    max6951_transmit
	move 	ACC, #6709h			;digit 7 = 9
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_9_nodecode	
;*
;* Set all digit registers to 9 in no decode mode	
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_9_nodecode:
	move 	ACC, #607Bh			;digit 0 = 9
	call    max6951_transmit
	move 	ACC, #617Bh			;digit 1 = 9
	call    max6951_transmit
	move 	ACC, #627Bh			;digit 2 = 9
	call    max6951_transmit
	move 	ACC, #637Bh			;digit 3 = 9
	call    max6951_transmit
	move 	ACC, #647Bh			;digit 4 = 9
	call    max6951_transmit
	move 	ACC, #657Bh			;digit 5 = 9
	call    max6951_transmit
	move 	ACC, #667Bh			;digit 6 = 9
	call    max6951_transmit
	move 	ACC, #677Bh			;digit 7 = 9
	call    max6951_transmit
	RET
	
;*******************************************************************************
;* Function:  max6951_set_all_A
;*
;* Set all digit registers to A
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_A:
	move 	ACC, #600Ah			;digit 0 = A
	call    max6951_transmit
	move 	ACC, #610Ah			;digit 1 = A
	call    max6951_transmit
	move 	ACC, #620Ah			;digit 2 = A
	call    max6951_transmit
	move 	ACC, #630Ah			;digit 3 = A
	call    max6951_transmit
	move 	ACC, #640Ah			;digit 4 = A
	call    max6951_transmit
	move 	ACC, #650Ah			;digit 5 = A
	call    max6951_transmit
	move 	ACC, #660Ah			;digit 6 = A
	call    max6951_transmit
	move 	ACC, #670Ah			;digit 7 = A
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_A_nodecode	
;*
;* Set all digit registers to A in no decode mode			
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_A_nodecode:
	move 	ACC, #6077h			;digit 0 = A
	call    max6951_transmit
	move 	ACC, #6177h			;digit 1 = A
	call    max6951_transmit
	move 	ACC, #6277h			;digit 2 = A
	call    max6951_transmit
	move 	ACC, #6377h			;digit 3 = A
	call    max6951_transmit
	move 	ACC, #6477h			;digit 4 = A
	call    max6951_transmit
	move 	ACC, #6577h			;digit 5 = A
	call    max6951_transmit
	move 	ACC, #6677h			;digit 6 = A
	call    max6951_transmit
	move 	ACC, #6777h			;digit 7 = A
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_B
;*
;* Set all digit registers to B
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_B:
	move 	ACC, #600Bh			;digit 0 = B
	call    max6951_transmit
	move 	ACC, #610Bh			;digit 1 = B
	call    max6951_transmit
	move 	ACC, #620Bh			;digit 2 = B
	call    max6951_transmit
	move 	ACC, #630Bh			;digit 3 = B
	call    max6951_transmit
	move 	ACC, #640Bh			;digit 4 = B
	call    max6951_transmit
	move 	ACC, #650Bh			;digit 5 = B
	call    max6951_transmit
	move 	ACC, #660Bh			;digit 6 = B
	call    max6951_transmit
	move 	ACC, #670Bh			;digit 7 = B
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_B_nodecode	
;*
;* Set all digit registers to B in no decode mode
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_B_nodecode:
	move 	ACC, #601Fh			;digit 0 = B
	call    max6951_transmit
	move 	ACC, #611Fh			;digit 1 = B
	call    max6951_transmit
	move 	ACC, #621Fh			;digit 2 = B
	call    max6951_transmit
	move 	ACC, #631Fh			;digit 3 = B
	call    max6951_transmit
	move 	ACC, #641Fh			;digit 4 = B
	call    max6951_transmit
	move 	ACC, #651Fh			;digit 5 = B
	call    max6951_transmit
	move 	ACC, #661Fh			;digit 6 = B
	call    max6951_transmit
	move 	ACC, #671Fh			;digit 7 = B
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_C
;*
;* Set all digit registers to C
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_C:
	move 	ACC, #600Ch			;digit 0 = C
	call    max6951_transmit
	move 	ACC, #610Ch			;digit 1 = C
	call    max6951_transmit
	move 	ACC, #620Ch			;digit 2 = C
	call    max6951_transmit
	move 	ACC, #630Ch			;digit 3 = C
	call    max6951_transmit
	move 	ACC, #640Ch			;digit 4 = C
	call    max6951_transmit
	move 	ACC, #650Ch			;digit 5 = C
	call    max6951_transmit
	move 	ACC, #660Ch			;digit 6 = C
	call    max6951_transmit
	move 	ACC, #670Ch			;digit 7 = C
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_C_nodecode	
;*
;* Set all digit registers to C in no decode mode
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_C_nodecode:
	move 	ACC, #604Eh			;digit 0 = C
	call    max6951_transmit
	move 	ACC, #614Eh			;digit 1 = C
	call    max6951_transmit
	move 	ACC, #624Eh			;digit 2 = C
	call    max6951_transmit
	move 	ACC, #634Eh			;digit 3 = C
	call    max6951_transmit
	move 	ACC, #644Eh			;digit 4 = C
	call    max6951_transmit
	move 	ACC, #654Eh			;digit 5 = C
	call    max6951_transmit
	move 	ACC, #664Eh			;digit 6 = C
	call    max6951_transmit
	move 	ACC, #674Eh			;digit 7 = C
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_D_nodecode		
;*
;* Set all digit registers to D in no decode mode
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_D_nodecode:
	move 	ACC, #603Dh			;digit 0 = D
	call    max6951_transmit
	move 	ACC, #613Dh			;digit 1 = D
	call    max6951_transmit
	move 	ACC, #623Dh			;digit 2 = D
	call    max6951_transmit
	move 	ACC, #633Dh			;digit 3 = D
	call    max6951_transmit
	move 	ACC, #643Dh			;digit 4 = D
	call    max6951_transmit
	move 	ACC, #653Dh			;digit 5 = D
	call    max6951_transmit
	move 	ACC, #663Dh			;digit 6 = D
	call    max6951_transmit
	move 	ACC, #673Dh			;digit 7 = D
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_D
;*
;* Set all digit registers to D
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_D:
	move 	ACC, #600Dh			;digit 0 = D
	call    max6951_transmit
	move 	ACC, #610Dh			;digit 1 = D
	call    max6951_transmit
	move 	ACC, #620Dh			;digit 2 = D
	call    max6951_transmit
	move 	ACC, #630Dh			;digit 3 = D
	call    max6951_transmit
	move 	ACC, #640Dh			;digit 4 = D
	call    max6951_transmit
	move 	ACC, #650Dh			;digit 5 = D
	call    max6951_transmit
	move 	ACC, #660Dh			;digit 6 = D
	call    max6951_transmit
	move 	ACC, #670Dh			;digit 7 = D
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_E
;*
;* Set all digit registers to E
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_E:
	move 	ACC, #600Eh			;digit 0 = E
	call    max6951_transmit
	move 	ACC, #610Eh			;digit 1 = E
	call    max6951_transmit
	move 	ACC, #620Eh			;digit 2 = E
	call    max6951_transmit
	move 	ACC, #630Eh			;digit 3 = E
	call    max6951_transmit
	move 	ACC, #640Eh			;digit 4 = E
	call    max6951_transmit
	move 	ACC, #650Eh			;digit 5 = E
	call    max6951_transmit
	move 	ACC, #660Eh			;digit 6 = E
	call    max6951_transmit
	move 	ACC, #670Eh			;digit 7 = E
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_E_nodecode
;*
;* Set all digit registers to E in no decode mode
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_E_nodecode:
	move 	ACC, #604Fh			;digit 0 = E
	call    max6951_transmit
	move 	ACC, #614Fh			;digit 1 = E
	call    max6951_transmit
	move 	ACC, #624Fh			;digit 2 = E
	call    max6951_transmit
	move 	ACC, #634Fh			;digit 3 = E
	call    max6951_transmit
	move 	ACC, #644Fh			;digit 4 = E
	call    max6951_transmit
	move 	ACC, #654Fh			;digit 5 = E
	call    max6951_transmit
	move 	ACC, #664Fh			;digit 6 = E
	call    max6951_transmit
	move 	ACC, #674Fh			;digit 7 = E
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_F
;*
;* Set all digit registers to F
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_F:
	move 	ACC, #600Fh			;digit 0 = F
	call    max6951_transmit
	move 	ACC, #610Fh			;digit 1 = F
	call    max6951_transmit
	move 	ACC, #620Fh			;digit 2 = F
	call    max6951_transmit
	move 	ACC, #630Fh			;digit 3 = F
	call    max6951_transmit
	move 	ACC, #640Fh			;digit 4 = F
	call    max6951_transmit
	move 	ACC, #650Fh			;digit 5 = F
	call    max6951_transmit
	move 	ACC, #660Fh			;digit 6 = F
	call    max6951_transmit
	move 	ACC, #670Fh			;digit 7 = F
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_F_nodecode		
;*
;* Set all digit registers to F in no decode mode
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_F_nodecode:
	move 	ACC, #6047h			;digit 0 = F
	call    max6951_transmit
	move 	ACC, #6147h			;digit 1 = F
	call    max6951_transmit
	move 	ACC, #6247h			;digit 2 = F
	call    max6951_transmit
	move 	ACC, #6347h			;digit 3 = F
	call    max6951_transmit
	move 	ACC, #6447h			;digit 4 = F
	call    max6951_transmit
	move 	ACC, #6547h			;digit 5 = F
	call    max6951_transmit
	move 	ACC, #6647h			;digit 6 = F
	call    max6951_transmit
	move 	ACC, #6747h			;digit 7 = F
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_H_nodecode		
;*
;* Set all digit registers to H in no decode mode
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_H_nodecode:
	move 	ACC, #6037h			;digit 0 = H
	call    max6951_transmit
	move 	ACC, #6137h			;digit 1 = H
	call    max6951_transmit
	move 	ACC, #6237h			;digit 2 = H
	call    max6951_transmit
	move 	ACC, #6337h			;digit 3 = H
	call    max6951_transmit
	move 	ACC, #6437h			;digit 4 = H
	call    max6951_transmit
	move 	ACC, #6537h			;digit 5 = H
	call    max6951_transmit
	move 	ACC, #6637h			;digit 6 = H
	call    max6951_transmit
	move 	ACC, #6737h			;digit 7 = H
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_L_nodecode		
;*
;* Set all digit registers to L in no decode mode
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_L_nodecode:
	move 	ACC, #600Eh			;digit 0 = L
	call    max6951_transmit
	move 	ACC, #610Eh			;digit 1 = L
	call    max6951_transmit
	move 	ACC, #620Eh			;digit 2 = L
	call    max6951_transmit
	move 	ACC, #630Eh			;digit 3 = L
	call    max6951_transmit
	move 	ACC, #640Eh			;digit 4 = L
	call    max6951_transmit
	move 	ACC, #650Eh			;digit 5 = L
	call    max6951_transmit
	move 	ACC, #660Eh			;digit 6 = L
	call    max6951_transmit
	move 	ACC, #670Eh			;digit 7 = L
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_P_nodecode		
;*
;* Set all digit registers to P in no decode mode
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_P_nodecode:
	move 	ACC, #6067h			;digit 0 = P
	call    max6951_transmit
	move 	ACC, #6167h			;digit 1 = P
	call    max6951_transmit
	move 	ACC, #6267h			;digit 2 = P
	call    max6951_transmit
	move 	ACC, #6367h			;digit 3 = P
	call    max6951_transmit
	move 	ACC, #6467h			;digit 4 = P
	call    max6951_transmit
	move 	ACC, #6567h			;digit 5 = P
	call    max6951_transmit
	move 	ACC, #6667h			;digit 6 = P
	call    max6951_transmit
	move 	ACC, #6767h			;digit 7 = P
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_Q_nodecode		
;*
;* Set all digit registers to Q in no decode mode
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_Q_nodecode:
	move 	ACC, #6073h			;digit 0 = Q
	call    max6951_transmit
	move 	ACC, #6173h			;digit 1 = Q
	call    max6951_transmit
	move 	ACC, #6273h			;digit 2 = Q
	call    max6951_transmit
	move 	ACC, #6373h			;digit 3 = Q
	call    max6951_transmit
	move 	ACC, #6473h			;digit 4 = Q
	call    max6951_transmit
	move 	ACC, #6573h			;digit 5 = Q
	call    max6951_transmit
	move 	ACC, #6673h			;digit 6 = Q
	call    max6951_transmit
	move 	ACC, #6773h			;digit 7 = Q
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_all_Y_nodecode		
;*
;* Set all digit registers to Y in no decode mode
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_all_Y_nodecode:
	move 	ACC, #603Bh			;digit 0 = Y
	call    max6951_transmit
	move 	ACC, #613Bh			;digit 1 = Y
	call    max6951_transmit
	move 	ACC, #623Bh			;digit 2 = Y
	call    max6951_transmit
	move 	ACC, #633Bh			;digit 3 = Y
	call    max6951_transmit
	move 	ACC, #643Bh			;digit 4 = Y
	call    max6951_transmit
	move 	ACC, #653Bh			;digit 5 = Y
	call    max6951_transmit
	move 	ACC, #663Bh			;digit 6 = Y
	call    max6951_transmit
	move 	ACC, #673Bh			;digit 7 = Y
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_blank_nodecode		
;*
;* Set all digit registers to blank in no decode mode
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_blank_nodecode:
	move 	ACC, #6000h			;digit 0 = blank
	call    max6951_transmit
	move 	ACC, #6100h			;digit 1 = blank
	call    max6951_transmit
	move 	ACC, #6200h			;digit 2 = blank
	call    max6951_transmit
	move 	ACC, #6300h			;digit 3 = blank
	call    max6951_transmit
	move 	ACC, #6400h			;digit 4 = blank
	call    max6951_transmit
	move 	ACC, #6500h			;digit 5 = blank
	call    max6951_transmit
	move 	ACC, #6600h			;digit 6 = blank
	call    max6951_transmit
	move 	ACC, #6700h			;digit 7 = blank
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_0_7
;*
;* Set 8 digit registers from 0 to 7
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_0_7:
	move 	ACC, #6000h			;digit 0 = 0
	call    max6951_transmit
	move 	ACC, #6101h			;digit 1 = 1
	call    max6951_transmit
	move 	ACC, #6202h			;digit 2 = 2
	call    max6951_transmit
	move 	ACC, #6303h			;digit 3 = 3
	call    max6951_transmit
	move 	ACC, #6404h			;digit 4 = 4
	call    max6951_transmit
	move 	ACC, #6505h			;digit 5 = 5
	call    max6951_transmit
	move 	ACC, #6606h			;digit 6 = 6
	call    max6951_transmit
	move 	ACC, #6707h			;digit 7 = 7
	call    max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_set_P0_0_7_P1_0
;*
;* Set 8 digit registers P0 from 0 to 7, all P1 = 0
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_set_P0_0_7_P1_0:
	move ACC, #2000h					; digit 0 P0 = 0
	call max6951_transmit
	move ACC, #4000h					; digit 0 P1 = 0
	call max6951_transmit
	move ACC, #2101h					; digit 1 P0 = 1
	call max6951_transmit
	move ACC, #4100h					; digit 1 P1 = 0
	call max6951_transmit
	move ACC, #2202h					; digit 2 P0 = 2
	call max6951_transmit
	move ACC, #4200h					; digit 2 P1 = 0
	call max6951_transmit
	move ACC, #2303h					; digit 3 P0 = 3
	call max6951_transmit
	move ACC, #4300h					; digit 3 P1 = 0
	call max6951_transmit
	move ACC, #2404h					; digit 4 P0 = 4
	call max6951_transmit
	move ACC, #4400h					; digit 4 P0 = 0
	call max6951_transmit
	move ACC, #2505h					; digit 5 P0 = 5
	call max6951_transmit
	move ACC, #4500h					; digit 5 P0 = 0
	call max6951_transmit
	move ACC, #2606h					; digit 6 P0 = 6
	call max6951_transmit
	move ACC, #4600h					; digit 6 P0 = 0
	call max6951_transmit
	move ACC, #2707h					; digit 7 P0 = 7
	call max6951_transmit
	move ACC, #4700h					; digit 7 P0 = 0
	call max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_light_all
;*
;* Light all segments  
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_light_all:
	move 	ACC, #6088h			;digit 0 = 8.
	call    max6951_transmit
	move 	ACC, #6188h			;digit 1 = 8.
	call    max6951_transmit
	move 	ACC, #6288h			;digit 2 = 8.
	call    max6951_transmit
	move 	ACC, #6388h			;digit 3 = 8.
	call    max6951_transmit
	move 	ACC, #6488h			;digit 4 = 8.
	call    max6951_transmit
	move 	ACC, #6588h			;digit 5 = 8.
	call    max6951_transmit
	move 	ACC, #6688h			;digit 6 = 8.
	call    max6951_transmit
	move 	ACC, #6788h			;digit 7 = 8.
	call    max6951_transmit
 	RET

;*******************************************************************************
;* Function:  max6951_light_all_nodecode
;*
;* Light all segments in no decode mode  
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_light_all_nodecode:
	move 	ACC, #60FFh			;digit 0 = 8.
	call    max6951_transmit
	move 	ACC, #61FFh			;digit 1 = 8.
	call    max6951_transmit
	move 	ACC, #62FFh			;digit 2 = 8.
	call    max6951_transmit
	move 	ACC, #63FFh			;digit 3 = 8.
	call    max6951_transmit
	move 	ACC, #64FFh			;digit 4 = 8.
	call    max6951_transmit
	move 	ACC, #65FFh			;digit 5 = 8.
	call    max6951_transmit
	move 	ACC, #66FFh			;digit 6 = 8.
	call    max6951_transmit
	move 	ACC, #67FFh			;digit 7 = 8.
	call    max6951_transmit
 	RET

;*******************************************************************************
;* Function:  max6951_one_second_delay
;*
;* This routine delays one second.
;*
;* Input:     LC[0], LC[1]
;* 
;* Output:    None.
;*
;* Destroys:  LC[0], LC[1]
;*
;*******************************************************************************
max6951_one_second_delay:			; 16,000 * 1000 clocks = 1 second
	move	LC[1], #03E8h
loop0:
	move 	LC[0], #3E80h			 
loop1:
	djnz	LC[0], loop1
	djnz	LC[1], loop0
	RET

;*******************************************************************************
;* Function:  max6951_half_second_delay
;*
;* This routine delays half second.
;*
;* Input:     LC[0], LC[1]
;* 
;* Output:    None.
;*
;* Destroys:  LC[0], LC[1]
;*
;*******************************************************************************
max6951_half_second_delay:			; 16,000 * 500 clocks = 0.5 second
	move	LC[1], #01F4h
loop2:
	move 	LC[0], #3E80h			 
loop3:
	djnz	LC[0], loop3
	djnz	LC[1], loop2
	RET

;*******************************************************************************
;* Function:  max6951_100ms_delay
;*
;* delay 100 millisecond 
;*
;* Input:     LC[0], LC[1]
;* 
;* Output:    None.
;*
;* Destroys:  LC[0], LC[1]
;*
;*******************************************************************************
max6951_100ms_delay:			; 16,000 * 100 clocks = 100 millisecond
	move	LC[1], #0064h
loop4:
	move 	LC[0], #3E80h			 
loop5:
	djnz	LC[0], loop5
	djnz	LC[1], loop4
	RET

;*******************************************************************************
;* Function:  max6951_10ms_delay
;*
;* delay 10 millisecond 
;*
;* Input:     LC[0], LC[1]
;* 
;* Output:    None.
;*
;* Destroys:  LC[0], LC[1]
;*
;*******************************************************************************
max6951_10ms_delay:			; 16,000 * 10 clocks = 10 millisecond
	move	LC[1], #000Ah
loop6:
	move 	LC[0], #3E80h			 
loop7:
	djnz	LC[0], loop7
	djnz	LC[1], loop6
	RET
;*******************************************************************************
;* Function:  max6951_e_d_s_d
;*
;* enable display, delay half second, shutdown display, delay 100 millisecond 
;*
;* Input:     ACC, LC[0], LC[1]
;* 
;* Output:    None.
;*
;* Destroys:  ACC, LC[0], LC[1] 
;*
;*******************************************************************************
max6951_e_d_s_d:
	call max6951_enable
	call max6951_half_second_delay	
	call max6951_shutdown
	call max6951_100ms_delay
	RET

;*******************************************************************************
;* Function:  font_lookup
;*
;* Given a digit value in hexadecimal format, this routine looks for the value 
;* 
;* that displays the same font in no decode mode on a standard 7-segment LED.  
;*
;* Input:     ACC
;* 
;* Output:    A[9]
;*
;* Destroys:  PSF 
;*
;*******************************************************************************
font_lookup:
	CMP		#00h				 
	move 	A[9], #07Eh			; font 0 = 7Eh
	JUMP 	E, lookup_complete
	CMP		#01h
	move	A[9], #30h			; font 1 = 30h
	JUMP 	E, lookup_complete
	CMP		#02h
	move	A[9], #6Dh			; font 2 = 6Dh
	JUMP 	E, lookup_complete	 
	CMP		#03h
	move	A[9], #79h			; font 3 = 79h
	JUMP 	E, lookup_complete			
	CMP		#04h
	move	A[9], #33h			; font 4 = 33h
	JUMP 	E, lookup_complete	
	CMP		#05h
	move	A[9], #5Bh			; font 5 = 5Bh
	JUMP 	E, lookup_complete
	CMP		#06h
	move	A[9], #5Fh			; font 6 = 9Fh
	JUMP 	E, lookup_complete
	CMP		#07h
	move	A[9], #70h			; font 7 = 70h
	JUMP 	E, lookup_complete
	CMP		#08h
	move	A[9], #7Fh			; font 8 = 7Fh
	JUMP 	E, lookup_complete
	CMP		#09h
	move	A[9], #7Bh			; font 9 = 7Bh
	JUMP 	E, lookup_complete
	CMP		#0Ah
	move	A[9], #77h			; font A = 77h
	JUMP 	E, lookup_complete
	CMP		#0Bh
	move	A[9], #1Fh			; font B = 1Fh
	JUMP 	E, lookup_complete
	CMP		#0Ch
	move	A[9], #4Eh			; font C = 4Eh
	JUMP 	E, lookup_complete
	CMP		#0Dh
	move	A[9], #3Fh			; font D = 3Fh
	JUMP 	E, lookup_complete
	CMP		#0Eh
	move	A[9], #4Fh			; font E = 4Fh
	JUMP 	E, lookup_complete
	CMP		#0Fh
	move	A[9], #47h			; font F = 47h
lookup_complete:
	RET

;*******************************************************************************
;* Function:  max6951_counting
;*
;* This routine counts how many 10-milliseconds have ellapsed and displays 
;*
;* the value from 0000 to 9999 on LED digits 3-0 (no way to blank leading digits).
;*
;  The routine displays the same value on LED digits 7-4 ( by using no decode
;* 
;* mode, individual leading digits can be blanked).
;*
;* Input:     None
;* 
;* Output:    None
;*
;* Destroys:  ACC, A[1] - A[4], A[9] 
;*
;*******************************************************************************
max6951_counting:
	call 	max6951_shutdown
	call	max6951_set_all_0	; set all bits of data registers to 0
	move    ACC, #010Fh			; hexdecimal decode digits 3-0, no deocde digits 7-4		
	call	max6951_transmit
	; initialize the count to 0	
	move	A[1], #0			; A[1] => digit 0
	move	A[2], #0			; A[2] => digit 1
	move	A[3], #0			; A[3] => digit 2
	move	A[4], #0			; A[4] => digit 3

count_loop:	
increase_digit3:
	move	ACC, A[4]			; process digit 3  	
	sub		#9
	jump	z, increase_digit2	; digit 3 = 9, there is carry over
	move	ACC, A[4]			; digit 3 < 9, continue
	ADD		#1
	move	A[4], ACC
	call	font_lookup			; look up the value for this font
								; store it in A[9], keep ACC unchanged 
	or		#6300h
	call	max6951_transmit	; no carry over, write digit 3 new value
	move	ACC, A[9]			; write the no decode value to digit 7 
	or      #6700h
	call	max6951_transmit
	jump	display_number

increase_digit2:
	or		#6300h
	call	max6951_transmit	; write 0 to digit 3 register first
	move	A[4], #0			; set digit 3 back to 0
	move	ACC, #677Eh			; no decode value for font '0' is "7Eh"
	call 	max6951_transmit 	; write 7Eh to digit 7 register

	move	ACC, A[3]			; process digit 2
	sub		#9
	jump	z, increase_digit1	; digit 2 = 9, there is carry over
	move	ACC, A[3]			; digit 2 < 9, continue
	ADD		#1
	move	A[3], ACC
	call	font_lookup			; look up the value for this font
								; store it in A[9], keep ACC unchanged 
	or		#6200h
	call	max6951_transmit	; no carry over, write digit 2 new value
	move	ACC, A[9]			; write the no decode value to digit 6 
	or      #6600h
	call	max6951_transmit
	jump	display_number

increase_digit1:
	or		#6200h
	call	max6951_transmit	; write 0 to digit 2 register first
	move	A[3], #0			; set digit 2 back to 0
	move	ACC, #667Eh			; no decode value for font '0' is "7Eh"
	call 	max6951_transmit 	; write 7Eh to digit 6 register 

	move	ACC, A[2]			; process digit 1
	sub		#9
	jump	z, increase_digit0	; digit 1 = 9, there is carry over
	move	ACC, A[2]			; digit 1 < 9, continue
	ADD		#1
	move	A[2], ACC
	call	font_lookup			; look up the value for this font
								; store it in A[9], keep ACC unchanged 
	or		#6100h
	call	max6951_transmit	; no carry over, write digit 1 new value
	move	ACC, A[9]			; write the no decode value to digit 5 
	or      #6500h
	call	max6951_transmit
	jump	display_number

increase_digit0:
	or		#6100h
	call	max6951_transmit	; write 0 to digit 1 register first
	move	A[2], #0			; set digit 1 back to 0
	move	ACC, #657Eh			; no decode value for font '0' is "7Eh"
	call 	max6951_transmit 	; wirte 7Eh to digit 5 register
 
	move	ACC, A[1]			; process digit 0
	sub		#9
	jump	z, count_complete	; digit 0 = 9, counting is over
	move	ACC, A[1]			; digit 0 < 9, continue
	ADD		#1
	move	A[1], ACC
	call	font_lookup			; look up the value for this font
								; store it in A[9], keep ACC unchanged 
	or		#6000h
	call	max6951_transmit	; no carry over, write digit 0 new value
	move	ACC, A[9]			; write the no decode value to digit 4 
	or      #6400h
	call	max6951_transmit

display_number:					; display digit 3-0 in hexadecimal decode mode
								; dieplay digit 7-4 in no decode mode
	call	max6951_enable
	call	max6951_10ms_delay
	jump 	count_loop

count_complete:
	RET

;*******************************************************************************
;* Function:  max6951_screenshot0		
;*
;* In no decode mode, display "XXXHELLO"   
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_screenshot0:
	move	ACC, #6000h				; digit 0 = blank
	call	max6951_transmit
	move	ACC, #6100h				; digit 1 = blank
	call	max6951_transmit	
	move	ACC, #6200h				; digit 2 = blank
	call	max6951_transmit
	move	ACC, #6337h				; digit 3 = H
	call	max6951_transmit
	move	ACC, #644Fh 			; digit 4 = E
	call	max6951_transmit
	move	ACC, #650Eh 			; digit 5 = L
	call	max6951_transmit
	move	ACC, #660Eh 			; digit 6 = L
	call	max6951_transmit
	move	ACC, #677Eh 			; digit 7 = O
	call	max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_screenshot1		
;*
;* In no decode mode, display "XXHELLOX"   
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_screenshot1:
	move	ACC, #6000h				; digit 0 = blank
	call	max6951_transmit
	move	ACC, #6100h				; digit 1 = blank
	call	max6951_transmit	
	move	ACC, #6237h				; digit 2 = H
	call	max6951_transmit
	move	ACC, #634Fh				; digit 3 = E
	call	max6951_transmit
	move	ACC, #640Eh 			; digit 4 = L
	call	max6951_transmit
	move	ACC, #650Eh 			; digit 5 = L
	call	max6951_transmit
	move	ACC, #667Eh 			; digit 6 = O
	call	max6951_transmit
	move	ACC, #6700h 			; digit 7 = blank
	call	max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_screenshot2		
;*
;* In no decode mode, display "XHELLOXX"   
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_screenshot2:
	move	ACC, #6000h				; digit 0 = blank
	call	max6951_transmit
	move	ACC, #6137h				; digit 1 = H
	call	max6951_transmit	
	move	ACC, #624Fh				; digit 2 = E
	call	max6951_transmit
	move	ACC, #630Eh				; digit 3 = L
	call	max6951_transmit
	move	ACC, #640Eh 			; digit 4 = L
	call	max6951_transmit
	move	ACC, #657Eh 			; digit 5 = O
	call	max6951_transmit
	move	ACC, #6600h 			; digit 6 = blank
	call	max6951_transmit
	move	ACC, #6700h 			; digit 7 = blank
	call	max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_screenshot3		
;*
;* In no decode mode, display "HELLOXXX"   
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_screenshot3:
	move	ACC, #6037h				; digit 0 = H
	call	max6951_transmit
	move	ACC, #614Fh				; digit 1 = E
	call	max6951_transmit	
	move	ACC, #620Eh				; digit 2 = L
	call	max6951_transmit
	move	ACC, #630Eh				; digit 3 = L
	call	max6951_transmit
	move	ACC, #647Eh 			; digit 4 = O
	call	max6951_transmit
	move	ACC, #6500h 			; digit 5 = blank
	call	max6951_transmit
	move	ACC, #6600h 			; digit 6 = blank
	call	max6951_transmit
	move	ACC, #6700h 			; digit 7 = blank
	call	max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_screenshot4		
;*
;* In no decode mode, display "ELLOXXXH"   
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_screenshot4:
	move	ACC, #604Fh				; digit 0 = E
	call	max6951_transmit
	move	ACC, #610Eh				; digit 1 = L
	call	max6951_transmit	
	move	ACC, #620Eh				; digit 2 = L
	call	max6951_transmit
	move	ACC, #637Eh				; digit 3 = O
	call	max6951_transmit
	move	ACC, #6400h 			; digit 4 = blank
	call	max6951_transmit
	move	ACC, #6500h 			; digit 5 = blank
	call	max6951_transmit
	move	ACC, #6600h 			; digit 6 = blank
	call	max6951_transmit
	move	ACC, #6737h 			; digit 7 = H
	call	max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_screenshot5		
;*
;* In no decode mode, display "LLOXXXHE"   
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_screenshot5:
	move	ACC, #600Eh				; digit 0 = L
	call	max6951_transmit
	move	ACC, #610Eh				; digit 1 = L
	call	max6951_transmit	
	move	ACC, #627Eh				; digit 2 = O
	call	max6951_transmit
	move	ACC, #6300h				; digit 3 = blank
	call	max6951_transmit
	move	ACC, #6400h 			; digit 4 = blank
	call	max6951_transmit
	move	ACC, #6500h 			; digit 5 = blank
	call	max6951_transmit
	move	ACC, #6637h 			; digit 6 = H
	call	max6951_transmit
	move	ACC, #674Fh 			; digit 7 = E
	call	max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_screenshot6		
;*
;* In no decode mode, display "LOXXXHEL"   
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_screenshot6:
	move	ACC, #600Eh				; digit 0 = L
	call	max6951_transmit
	move	ACC, #617Eh				; digit 1 = O
	call	max6951_transmit	
	move	ACC, #6200h				; digit 2 = blank
	call	max6951_transmit
	move	ACC, #6300h				; digit 3 = blank
	call	max6951_transmit
	move	ACC, #6400h 			; digit 4 = blank
	call	max6951_transmit
	move	ACC, #6537h 			; digit 5 = H
	call	max6951_transmit
	move	ACC, #664Fh 			; digit 6 = E
	call	max6951_transmit
	move	ACC, #670Eh 			; digit 7 = L
	call	max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_screenshot7		
;*
;* In no decode mode, display "OXXXHELL"   
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_screenshot7:
	move	ACC, #607Eh				; digit 0 = O
	call	max6951_transmit
	move	ACC, #6100h				; digit 1 = blank
	call	max6951_transmit	
	move	ACC, #6200h				; digit 2 = blank
	call	max6951_transmit
	move	ACC, #6300h				; digit 3 = Blank
	call	max6951_transmit
	move	ACC, #6437h 			; digit 4 = H
	call	max6951_transmit
	move	ACC, #654Fh 			; digit 5 = E
	call	max6951_transmit
	move	ACC, #660Eh 			; digit 6 = L
	call	max6951_transmit
	move	ACC, #670Eh 			; digit 7 = L
	call	max6951_transmit
	RET

;*******************************************************************************
;* Function:  max6951_scroll_R_to_L		
;*
;* In no decode mode, display and scroll "HELLO" from right to left  
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_scroll_R_to_L:
	move 	ACC, #0100h					; put the MAX6951 in no docode mode
	call	max6951_transmit
	move    A[11], #0Ah					; inital loop count = 10, loop 10 times
scroll_loop1:
	move 	ACC, A[11]
	sub		#1							; loop count-1 before every loop
	move 	A[11], ACC

	call	max6951_screenshot0			; display screenshot sequence:
	call	max6951_enable
	call 	max6951_100ms_delay			; 0-1-2-3-4-5-6-7-0-1-2-3-4-5-6-7 ...
	call 	max6951_100ms_delay
	call	max6951_shutdown			; recursively
	call	max6951_screenshot1
	call	max6951_enable
	call 	max6951_100ms_delay
	call 	max6951_100ms_delay
	call	max6951_shutdown
	call	max6951_screenshot2
	call	max6951_enable
	call 	max6951_100ms_delay
	call 	max6951_100ms_delay
	call	max6951_shutdown
	call	max6951_screenshot3
	call	max6951_enable
	call 	max6951_100ms_delay
	call 	max6951_100ms_delay
	call	max6951_shutdown
	call	max6951_screenshot4
	call	max6951_enable
	call 	max6951_100ms_delay
	call 	max6951_100ms_delay
	call	max6951_shutdown
	call	max6951_screenshot5	
	call	max6951_enable
	call 	max6951_100ms_delay
	call 	max6951_100ms_delay
	call	max6951_shutdown
	call	max6951_screenshot6
	call	max6951_enable
	call 	max6951_100ms_delay
	call 	max6951_100ms_delay
	call	max6951_shutdown
	call	max6951_screenshot7
	call	max6951_enable
	call 	max6951_100ms_delay
	call 	max6951_100ms_delay
	call	max6951_shutdown

	move 	LC[0], A[11]				; test the end of the loop
	DJNZ	LC[0], scroll_loop1	
	RET

;*******************************************************************************
;* Function:  max6951_scroll_L_to_R		
;*
;* In no decode mode, display and scroll "HELLO" from left to right  
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC
;*
;*******************************************************************************
max6951_scroll_L_to_R:
	move 	ACC, #0100h					; put the MAX6951 in no docode mode
	call	max6951_transmit
	move    A[11], #0Ah					; inital loop count = 10, loop 10 times
scroll_loop2:
	move 	ACC, A[11]
	sub		#1							; loop count-1 before every loop
	move 	A[11], ACC

	call	max6951_screenshot3			; display screenshot sequence: 
	call	max6951_enable
	call 	max6951_100ms_delay			; 3-2-1-0-7-6-5-4-3-2-1-0-7-6-5-4 ....
	call 	max6951_100ms_delay
	call	max6951_shutdown			; recursively	
	call	max6951_screenshot2
	call	max6951_enable
	call 	max6951_100ms_delay
	call 	max6951_100ms_delay
	call	max6951_shutdown
	call	max6951_screenshot1
	call	max6951_enable
	call 	max6951_100ms_delay
	call 	max6951_100ms_delay
	call	max6951_shutdown
	call	max6951_screenshot0
	call	max6951_enable
	call 	max6951_100ms_delay
	call 	max6951_100ms_delay
	call	max6951_shutdown
	call	max6951_screenshot7
	call	max6951_enable
	call 	max6951_100ms_delay
	call 	max6951_100ms_delay
	call	max6951_shutdown
	call	max6951_screenshot6	
	call	max6951_enable
	call 	max6951_100ms_delay
	call 	max6951_100ms_delay
	call	max6951_shutdown
	call	max6951_screenshot5
	call	max6951_enable
	call 	max6951_100ms_delay
	call 	max6951_100ms_delay
	call	max6951_shutdown
	call	max6951_screenshot4
	call	max6951_enable
	call 	max6951_100ms_delay
	call 	max6951_100ms_delay
	call	max6951_shutdown

	move 	LC[0], A[11]				; test the end of the loop
	DJNZ	LC[0], scroll_loop2	
	
	RET

;*******************************************************************************
;* Function:  max6951_bouncing		
;*
;* In no decode mode, display and bounce "HELLO" between the two LED edges.  
;*
;* Input:     None.
;*
;* Output:    None.
;*
;* Destroys:  ACC, A[11]
;*
;*******************************************************************************
max6951_bouncing:
	move 	ACC, #0100h					; put the MAX6951 in no docode mode
	call	max6951_transmit
	move    A[11], #0Ah					; inital loop count = 10, loop 10 times
bouncing_loop:
	move 	ACC, A[11]
	sub		#1							; loop count-1 before every loop
	move 	A[11], ACC

	call	max6951_screenshot0			; display screenshot sequence:
	call	max6951_enable
	call 	max6951_100ms_delay			; 0-1-2-3-2-1-0-1-2-3-2-1 ...
	call 	max6951_100ms_delay
	call	max6951_shutdown			; recursively
	call	max6951_screenshot1
	call	max6951_enable
	call 	max6951_100ms_delay
	call 	max6951_100ms_delay
	call	max6951_shutdown
	call	max6951_screenshot2
	call	max6951_enable
	call 	max6951_100ms_delay
	call 	max6951_100ms_delay
	call	max6951_shutdown
	call	max6951_screenshot3
	call	max6951_enable
	call 	max6951_100ms_delay
	call 	max6951_100ms_delay
	call	max6951_shutdown
	call	max6951_screenshot2
	call	max6951_enable
	call 	max6951_100ms_delay
	call 	max6951_100ms_delay
	call	max6951_shutdown
	call	max6951_screenshot1	
	call	max6951_enable
	call 	max6951_100ms_delay
	call 	max6951_100ms_delay
	call	max6951_shutdown

	move 	LC[0], A[11]				; test the end of the loop
	DJNZ	LC[0], bouncing_loop	
	RET
	
END
